@@ -30,9 +30,9 @@ class ImplicitApplication(BaseAuthBackend):
         self.redirect_uri = redirect_uri
 
         # Generate correct URLs
-        self.base_url = f"{protocol}://{host}:{port}/o/"
-        self.auth_url = self.base_url + "authorize"
-        self.token_url = self.base_url + "token"
+        self.base_url = f"{protocol}://{host}:{port}/"
+        self.auth_url = self.base_url + "o/authorize"
+        self.token_url = self.base_url + "o/token"
 
         # If you want to have a hosting QtWidget
         self.parent = parent
@@ -51,9 +51,9 @@ class ImplicitApplication(BaseAuthBackend):
         )
 
 
-        super().__init__()
+        super().__init__(host, port, protocol=protocol)
 
-    def getToken(self, loop=None) -> str:
+    def fetchToken(self, loop=None) -> str:
 
         try:
             if not self.token:
