@@ -8,6 +8,8 @@ import logging
 from aiostream import stream
 import uuid
 from bergen.extenders.contexts.pod import HostedPod
+from tqdm import tqdm
+import textwrap
 
 class NodeExtender(BaseExtender):
 
@@ -41,7 +43,32 @@ class NodeExtender(BaseExtender):
 
     def stream(self, inputs: dict, params: AssignationParams = None, **kwargs):
 
-        return stream.iterate(self._postman.stream(self, inputs, params, **kwargs))
+        return stream.iterate(self._postman.stream(self, inputs, params, **kwargs)).stream()
+
+
+    async def assign_with_progress(self, inputs, params, **kwargs):
+        result = None
+        with tqdm(total=100) as pbar:
+                async with self.stream_progress(inputs, params, **kwargs) as stream:
+                        async for item in stream:
+                                result = item
+                                if isinstance(result, dict): break
+                                
+                                progress, message = item.split(":")
+                                try: 
+                                        pbar.n = int(progress)
+                                        pbar.refresh()
+                                except:
+                                        pass
+                                pbar.set_postfix_str(textwrap.shorten(message, width=30, placeholder="..."))
+                pbar.n = 100
+                pbar.refresh()
+                pbar.set_postfix_str("Done")
+        return result
+
+
+    def stream_progress(self,  inputs: dict, params: AssignationParams = None, **kwargs):
+        return stream.iterate(self._postman.stream_progress(self, inputs, params, **kwargs)).stream()
     
     def delay(self, inputs: dict, params: AssignationParams = None, **kwargs):
         if self._loop.is_running() and not self._force_sync:
@@ -51,7 +78,7 @@ class NodeExtender(BaseExtender):
             return result
 
 
-    def __call__(self, inputs: dict, params: AssignationParams = None, **kwargs) -> dict:
+    def __call__(self, inputs: dict, params: AssignationParams = None, with_progress = False, **kwargs) -> dict:
         """Call this node (can be run both asynchronously and syncrhounsly)
 
         Args:
@@ -62,9 +89,15 @@ class NodeExtender(BaseExtender):
             outputs (dict): The ooutputs of this Node
         """
         if self._loop.is_running() and not self._force_sync:
-            return self.assign_async(inputs, params, **kwargs)
+            if with_progress == True:
+                return self.assign_with_progress(inputs, params,  with_progress=with_progress, **kwargs)
+            return self.assign_async(inputs, params, with_progress=with_progress, **kwargs)
+
         else:
-            result = self._loop.run_until_complete(self.assign_async(inputs, params, **kwargs))
+            if with_progress == True:
+                return self._loop.run_until_complete(self.assign_with_progress(inputs, params,  with_progress=with_progress, **kwargs))
+
+            result = self._loop.run_until_complete(self.assign_async(inputs, params,  with_progress=with_progress, **kwargs))
             return result
 
 
