@@ -55,19 +55,18 @@ class GQL(object):
 class ListQuery(list):
 
 
-     def _repr_html_(self) -> str:
-        listified = list(self)
-        string = "Result List with <br/><table>"
-        for x, item in enumerate(listified):
-             string += f"""
-                <tr>
-                    <td>{x}<td/>
-                    <td>{item._repr_list_() if hasattr(item,"_repr_list_") else str(item)}</td>
-                </tr>
+    def __init__(self, *args, **kwargs):
+        self._df = None
+        super().__init__(*args, **kwargs)
 
-            """
-        string + "</table>"
-        return string
+
+    def to_df(self, exclude_unset=True, **kwargs):
+        import pandas as pd
+        if not self._df: self._df = pd.DataFrame.from_records([rec.dict(exclude_unset=exclude_unset, **kwargs) for rec in self])
+        return self._df
+
+    def _repr_html_(self) -> str:
+        return self.to_df().to_html()
 
 
     
@@ -88,7 +87,7 @@ class TypedGQL(GQL, Generic[MyType]):
         ward = ward or self._cls.get_ward()
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
         assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
-        if isinstance(returnedobject,list): return [self.cls(**item) for item in returnedobject]
+        if isinstance(returnedobject,list): return ListQuery([self.cls(**item) for item in returnedobject])
         return self.cls(**returnedobject)
 
     def run(self, ward=None, variables=None, **kwargs) -> MyType:
@@ -96,7 +95,7 @@ class TypedGQL(GQL, Generic[MyType]):
         ward = ward or self._cls.get_ward()
         returnedobject = ward.run(self, variables=variables, **kwargs)
         assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
-        if isinstance(returnedobject,list): return [self.cls(**item) for item in returnedobject]
+        if isinstance(returnedobject,list): return ListQuery([self.cls(**item) for item in returnedobject])
         return self.cls(**returnedobject)
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
@@ -159,7 +158,7 @@ class QueryList(GQL, Generic[MyType]):
         returnedobject = ward.run(self, variables=variables, **kwargs)
         assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
         assert isinstance(returnedobject,list), "Cannot unpack values, sure you are receiving a List?"
-        return [self.cls(**item) for item in returnedobject]
+        return ListQuery([self.cls(**item) for item in returnedobject])
 
     def subscribe(self, ward=None, **kwargs) -> Generator[List[MyType], None,None]:
         from bergen.registries.arnheim import get_current_arnheim
@@ -219,7 +218,7 @@ class AsyncQueryList(GQL, Generic[MyType]):
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
         assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
         assert isinstance(returnedobject,list), "Cannot unpack values, sure you are receiving a List?"
-        return [self.cls(**item) for item in returnedobject]
+        return ListQuery([self.cls(**item) for item in returnedobject])
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
         from bergen.registries.arnheim import get_current_arnheim
